spoon.ber.tag

Package spoon :: Package ber :: Module tag |
[hide private]
[frames] | no frames]

# Module tag

source code

Classes | [hide private]
`` | Tag Representation of the header of an ASN.1 object.

Variables | [hide private]
`` | _class_name = `{0: 'UNIVERSAL', 1: 'APPLICATION', 2: 'CONTEXT', 3: ...`

Variables Details | [hide private]

    ### _class_name None Value:
        {0: 'UNIVERSAL', 1: 'APPLICATION', 2: 'CONTEXT', 3: 'PRIVATE'}